@@ -8,6 +8,7 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
 
 from pycatia.drafting_interfaces.drawing_thread import DrawingThread
 from pycatia.system_interfaces.collection import Collection
@@ -152,5 +153,9 @@ class DrawingThreads(Collection):
 
         return DrawingThread(self.drawing_threads.item(n + 1))
 
+    def __iter__(self) -> Iterator[DrawingThread]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'DrawingThreads(name="{self.name}")'
