@@ -16,7 +16,6 @@ from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape
 
 
 class HybridShapeCurveSmooth(HybridShape):
-
     """
         .. note::
             :class: toggle
@@ -609,5 +608,382 @@ class HybridShapeCurveSmooth(HybridShape):
 
         self.hybrid_shape_curve_smooth.TopologySimplificationActivity = value
 
+    def add_frozen_curve_segment(self, i_curve: Reference) -> None:
+        """
+        .. note::
+            :class: toggle
+
+            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
+                | o Sub AddFrozenCurveSegment(Reference iCurve)
+                |
+                |     Adds a frozen curve to the hybrid shape curve smooth feature
+                |     object.
+                |
+                |     Parameters:
+                |
+                |         iCurve
+                |             The curve to be added to the hybrid shape curve smooth feature
+                |             object.
+                |
+                |     Example:
+                |         The following example adds the iCurve curve to the hybShpCurveSmooth
+                |         object.
+                |
+                |          hybShpCurveSmooth.AddFrozenCurveSegment iCurve
+
+        :param Reference i_curve:
+        :return: None
+        :rtype: None
+        """
+        return self.hybrid_shape_curve_smooth.AddFrozenCurveSegment(i_curve.com_object)
+        # # # # Autogenerated comment:
+        # # some methods require a system service call as the methods expects a vb array object
+        # # passed to it and there is no way to do this directly with python. In those cases the following code
+        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
+        # # vba_function_name = 'add_frozen_curve_segment'
+        # # vba_code = """
+        # # Public Function add_frozen_curve_segment(hybrid_shape_curve_smooth)
+        # #     Dim iCurve (2)
+        # #     hybrid_shape_curve_smooth.AddFrozenCurveSegment iCurve
+        # #     add_frozen_curve_segment = iCurve
+        # # End Function
+        # # """
+
+        # # system_service = SystemService(self.application.SystemService)
+        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+
+    def add_frozen_point(self, i_point: Reference) -> None:
+        """
+        .. note::
+            :class: toggle
+
+            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
+                | o Sub AddFrozenPoint(Reference iPoint)
+                |
+                |     Adds a frozen points to the hybrid shape curve smooth feature
+                |     object.
+                |
+                |     Parameters:
+                |
+                |         iPoint
+                |             The frozen point to be added to the hybrid shape curve smooth
+                |             feature object.
+                |
+                |     Example:
+                |         The following example adds the iPoint frozen point to the
+                |         hybShpCurveSmooth object.
+                |
+                |          hybShpCurveSmooth.AddFrozenPoint iPoint
+
+        :param Reference i_point:
+        :return: None
+        :rtype: None
+        """
+        return self.hybrid_shape_curve_smooth.AddFrozenPoint(i_point.com_object)
+        # # # # Autogenerated comment:
+        # # some methods require a system service call as the methods expects a vb array object
+        # # passed to it and there is no way to do this directly with python. In those cases the following code
+        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
+        # # vba_function_name = 'add_frozen_point'
+        # # vba_code = """
+        # # Public Function add_frozen_point(hybrid_shape_curve_smooth)
+        # #     Dim iPoint (2)
+        # #     hybrid_shape_curve_smooth.AddFrozenPoint iPoint
+        # #     add_frozen_point = iPoint
+        # # End Function
+        # # """
+
+        # # system_service = SystemService(self.application.SystemService)
+        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+
+    def get_frozen_curve_segment(self, i_pos: int) -> Reference:
+        """
+        .. note::
+            :class: toggle
+
+            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
+                | o Func GetFrozenCurveSegment(long iPos) As Reference
+                |
+                |     Retrieves the Frozen Curve Segment at specified position in the hybrid
+                |     shape curve smooth object.
+                |
+                |     Parameters:
+                |
+                |         iPos
+                |             The position of the Frozen Curve Segment to retrieve.
+                |
+                |
+                |     Example:
+                |         The following example gets the oCurve Frozen Curve Segment of the
+                |         hybShpCurveSmooth object at the position iPos.
+                |
+                |          Dim oCurve As Reference
+                |          Set oCurve = hybShpCurveSmooth.GetFrozenCurveSegment (iPos).
+
+        :param int i_pos:
+        :return: Reference
+        :rtype: Reference
+        """
+        return Reference(self.hybrid_shape_curve_smooth.GetFrozenCurveSegment(i_pos))
+
+    def get_frozen_curve_segments_size(self) -> int:
+        """
+        .. note::
+            :class: toggle
+
+            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
+                | o Func GetFrozenCurveSegmentsSize() As long
+                |
+                |     Returns the number of frozen curve segments in the curve smooth
+                |     object.
+                |
+                |     Parameters:
+                |
+                |         oSize
+                |             Number of frozen curve segments in the curve
+                |             smooth.
+                |
+                |             Example:
+                |                 This example retrieves the number of frozen curve segments. in
+                |                 the hybShpCurveSmooth hybrid shape curve
+                |                 smooth.
+                |
+                |                  Dim oSize As  long
+                |                  oSize = hybShpCurveSmooth.GetFrozenCurveSegmentsSize
+
+        :return: int
+        :rtype: int
+        """
+        return self.hybrid_shape_curve_smooth.GetFrozenCurveSegmentsSize()
+
+    def get_frozen_point(self, i_pos: int) -> Reference:
+        """
+        .. note::
+            :class: toggle
+
+            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
+                | o Func GetFrozenPoint(long iPos) As Reference
+                |
+                |     Retrieves the Frozen Point at specified position in the hybrid shape curve
+                |     smooth object.
+                |
+                |     Parameters:
+                |
+                |         iPos
+                |             The position of the Frozen Point to retrieve.
+                |
+                |     Example:
+                |         The following example gets the oPoint Frozen Point of the
+                |         hybShpCurveSmooth object at the position iPos.
+                |
+                |          Dim oPoint As Reference
+                |          Set oPoint = hybShpCurveSmooth.GetFrozenPoint (iPos).
+
+        :param int i_pos:
+        :return: Reference
+        :rtype: Reference
+        """
+        return Reference(self.hybrid_shape_curve_smooth.GetFrozenPoint(i_pos))
+
+    def get_frozen_points_size(self) -> int:
+        """
+        .. note::
+            :class: toggle
+
+            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
+                | o Func GetFrozenPointsSize() As long
+                |
+                |     Returns the number of Frozen Points in the curve smooth
+                |     object.
+                |
+                |     Parameters:
+                |
+                |         oSize
+                |             Number of Frozen Points in the curve smooth.
+                |
+                |             Example:
+                |                 This example retrieves the number of Frozen Points. in the
+                |                 hybShpCurveSmooth hybrid shape curve smooth.
+                |
+                |                  Dim oSize As  long
+                |                  oSize = hybShpCurveSmooth.GetFrozenPointsSize
+
+        :return: int
+        :rtype: int
+        """
+        return self.hybrid_shape_curve_smooth.GetFrozenPointsSize()
+
+    def remove_all_frozen_curve_segments(self) -> None:
+        """
+        .. note::
+            :class: toggle
+
+            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
+                | o Sub RemoveAllFrozenCurveSegments()
+                |
+                |     Removes all Frozen Curve Segment of the hybrid shape curve smooth object.
+                |
+                |
+                | Example:
+                |     The following example removes all Frozen Curve Segments of the
+                |     hybShpCurveSmooth object.
+                |
+                |      hybShpCurveSmooth.RemoveAllFrozenCurveSegments
+
+        :return: None
+        :rtype: None
+        """
+        return self.hybrid_shape_curve_smooth.RemoveAllFrozenCurveSegments()
+
+    def remove_all_frozen_points(self) -> None:
+        """
+        .. note::
+            :class: toggle
+
+            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
+                | o Sub RemoveAllFrozenPoints()
+                |
+                |     Removes all Frozen Points of the hybrid shape curve smooth object.
+                |
+                |
+                | Example:
+                |     The following example removes all Frozen Points of the hybShpCurveSmooth
+                |     object.
+                |
+                |      hybShpCurveSmooth.RemoveAllFrozenPoints
+
+        :return: None
+        :rtype: None
+        """
+        return self.hybrid_shape_curve_smooth.RemoveAllFrozenPoints()
+
+    def remove_frozen_curve_segment(self, i_curve: Reference) -> None:
+        """
+        .. note::
+            :class: toggle
+
+            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
+                | o Sub RemoveFrozenCurveSegment(Reference iCurve)
+                |
+                |     Removes Frozen Curve Segment from the list of Forzen curves in hybrid shape
+                |     curve smooth object.
+                |
+                |     Parameters:
+                |
+                |         iCurve
+                |             The Frozen Curve Segment to remove.
+                |
+                |     Example:
+                |         The following example removes the Frozen Curve Segment from the
+                |         hybShpCurveSmooth object.
+                |
+                |          hybShpCurveSmooth.RemoveFrozenCurveSegment iCurve.
+
+        :param Reference i_curve:
+        :return: None
+        :rtype: None
+        """
+        return self.hybrid_shape_curve_smooth.RemoveFrozenCurveSegment(i_curve.com_object)
+        # # # # Autogenerated comment:
+        # # some methods require a system service call as the methods expects a vb array object
+        # # passed to it and there is no way to do this directly with python. In those cases the following code
+        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
+        # # vba_function_name = 'remove_frozen_curve_segment'
+        # # vba_code = """
+        # # Public Function remove_frozen_curve_segment(hybrid_shape_curve_smooth)
+        # #     Dim iCurve (2)
+        # #     hybrid_shape_curve_smooth.RemoveFrozenCurveSegment iCurve
+        # #     remove_frozen_curve_segment = iCurve
+        # # End Function
+        # # """
+
+        # # system_service = SystemService(self.application.SystemService)
+        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+
+    def remove_frozen_point(self, i_point: Reference) -> None:
+        """
+        .. note::
+            :class: toggle
+
+            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
+                | o Sub RemoveFrozenPoint(Reference iPoint)
+                |
+                |     Removes Frozen Point from the list of frozen points in hybrid shape curve
+                |     smooth object.
+                |
+                |     Parameters:
+                |
+                |         iPoint
+                |             The Frozen Point to remove.
+                |
+                |     Example:
+                |         The following example removes the Frozen Point from the
+                |         hybShpCurveSmooth object.
+                |
+                |          hybShpCurveSmooth.RemoveFrozenPoint iPoint.
+
+        :param Reference i_point:
+        :return: None
+        :rtype: None
+        """
+        return self.hybrid_shape_curve_smooth.RemoveFrozenPoint(i_point.com_object)
+        # # # # Autogenerated comment:
+        # # some methods require a system service call as the methods expects a vb array object
+        # # passed to it and there is no way to do this directly with python. In those cases the following code
+        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
+        # # vba_function_name = 'remove_frozen_point'
+        # # vba_code = """
+        # # Public Function remove_frozen_point(hybrid_shape_curve_smooth)
+        # #     Dim iPoint (2)
+        # #     hybrid_shape_curve_smooth.RemoveFrozenPoint iPoint
+        # #     remove_frozen_point = iPoint
+        # # End Function
+        # # """
+
+        # # system_service = SystemService(self.application.SystemService)
+        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+
+    def set_maximum_deviation(self, i_max_deviation: float) -> None:
+        """
+        .. note::
+            :class: toggle
+
+            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
+                | o Sub SetMaximumDeviation(double iMaxDeviation)
+                |
+                |     Sets the maximum deviation.
+                |
+                |     Parameters:
+                |
+                |         iMaxDeviation
+                |             The maximium deviation
+
+        :param float i_max_deviation:
+        :return: None
+        :rtype: None
+        """
+        return self.hybrid_shape_curve_smooth.SetMaximumDeviation(i_max_deviation)
+
+    def set_tangency_threshold(self, i_tangency_threshold: float) -> None:
+        """
+        .. note::
+            :class: toggle
+
+            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
+                | o Sub SetTangencyThreshold(double iTangencyThreshold)
+                |
+                |     Sets the tangency threshold.
+                |
+                |     Parameters:
+                |
+                |         iTangencyThreshold
+                |             The tangency threshold
+
+        :param float i_tangency_threshold:
+        :return: None
+        :rtype: None
+        """
+        return self.hybrid_shape_curve_smooth.SetTangencyThreshold(i_tangency_threshold)
+
     def __repr__(self):
-        return f'HybridShapeCurveSmooth(name="{ self.name }")'
+        return f'HybridShapeCurveSmooth(name="{self.name}")'
