@@ -16,6 +16,8 @@ from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape
 class HybridShapeExtractMulti(HybridShape):
     """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
 
                 | System.IUnknown
@@ -46,6 +48,8 @@ class HybridShapeExtractMulti(HybridShape):
                        i_crvtre_thsld: float, i_pos: int) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub AddConstraint(Reference iConstraint,
                 | long iType,
@@ -112,7 +116,7 @@ class HybridShapeExtractMulti(HybridShape):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def add_constraint_tolerant(self, i_constraint: Reference, i_type: int, i_complementaire: bool,
@@ -120,6 +124,8 @@ class HybridShapeExtractMulti(HybridShape):
                                 i_crvtre_thsld: float, i_pos: int) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub AddConstraintTolerant(Reference iConstraint,
                 | long iType,
@@ -196,12 +202,14 @@ class HybridShapeExtractMulti(HybridShape):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def get_angular_threshold(self, i_pos: int) -> float:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetAngularThreshold(long iPos) As double
                 | 
@@ -225,6 +233,8 @@ class HybridShapeExtractMulti(HybridShape):
     def get_angular_threshold_activity(self, i_pos: int) -> bool:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetAngularThresholdActivity(long iPos) As boolean
                 | 
@@ -248,6 +258,8 @@ class HybridShapeExtractMulti(HybridShape):
     def get_complementary_extract_multi(self, i_pos: int) -> bool:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetComplementaryExtractMulti(long iPos) As boolean
                 | 
@@ -271,6 +283,8 @@ class HybridShapeExtractMulti(HybridShape):
     def get_curvature_threshold(self, i_pos: int) -> float:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetCurvatureThreshold(long iPos) As double
                 | 
@@ -294,6 +308,8 @@ class HybridShapeExtractMulti(HybridShape):
     def get_curvature_threshold_activity(self, i_pos: int) -> bool:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetCurvatureThresholdActivity(long iPos) As boolean
                 | 
@@ -317,6 +333,8 @@ class HybridShapeExtractMulti(HybridShape):
     def get_distance_threshold(self, i_pos: int) -> float:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetDistanceThreshold(long iPos) As double
                 | 
@@ -340,6 +358,8 @@ class HybridShapeExtractMulti(HybridShape):
     def get_distance_threshold_activity(self, i_pos: int) -> bool:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetDistanceThresholdActivity(long iPos) As boolean
                 | 
@@ -363,6 +383,8 @@ class HybridShapeExtractMulti(HybridShape):
     def get_element(self, i_pos: int) -> Reference:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetElement(long iPos) As Reference
                 | 
@@ -388,6 +410,8 @@ class HybridShapeExtractMulti(HybridShape):
     def get_is_federated(self, i_pos: int) -> bool:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetIsFederated(long iPos) As boolean
                 | 
@@ -411,6 +435,8 @@ class HybridShapeExtractMulti(HybridShape):
     def get_list_of_constraints(self, o_list_of_extracted_constraints: tuple) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetListOfConstraints(CATSafeArrayVariant
                 | oListOfExtractedConstraints)
@@ -459,12 +485,14 @@ class HybridShapeExtractMulti(HybridShape):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def get_nb_constraints(self, o_nb_constraints: int) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetNbConstraints(long oNbConstraints)
                 | 
@@ -494,6 +522,8 @@ class HybridShapeExtractMulti(HybridShape):
     def get_propagation_type(self, i_pos: int) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetPropagationType(long iPos) As long
                 | 
@@ -524,6 +554,8 @@ class HybridShapeExtractMulti(HybridShape):
     def get_support(self, i_pos: int) -> Reference:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetSupport(long iPos) As Reference
                 | 
@@ -544,6 +576,8 @@ class HybridShapeExtractMulti(HybridShape):
     def remove_element(self, i_position: int) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveElement(long iPosition)
                 | 
@@ -571,6 +605,8 @@ class HybridShapeExtractMulti(HybridShape):
     def replace_element(self, i_extract_to_replace: Reference, i_new_extract: Reference, i_pos: int) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub ReplaceElement(Reference iExtractToReplace,
                 | Reference iNewExtract,
@@ -619,12 +655,14 @@ class HybridShapeExtractMulti(HybridShape):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_angular_threshold(self, i_pos: int, i_angtre_thsld: float) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetAngularThreshold(long iPos,
                 | double iAngtreThsld)
@@ -650,6 +688,8 @@ class HybridShapeExtractMulti(HybridShape):
     def set_angular_threshold_activity(self, i_pos: int, i_angtre_thsld_activity: bool) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetAngularThresholdActivity(long iPos,
                 | boolean iAngtreThsldActivity)
@@ -685,12 +725,14 @@ class HybridShapeExtractMulti(HybridShape):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_complementary_extract_multi(self, i_pos: int, i_complementaire: bool) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetComplementaryExtractMulti(long iPos,
                 | boolean iComplementaire)
@@ -726,12 +768,14 @@ class HybridShapeExtractMulti(HybridShape):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_curvature_threshold(self, i_pos: int, i_crvtre_thsld: float) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetCurvatureThreshold(long iPos,
                 | double iCrvtreThsld)
@@ -757,6 +801,8 @@ class HybridShapeExtractMulti(HybridShape):
     def set_curvature_threshold_activity(self, i_pos: int, i_crvtre_thsld_activity: bool) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetCurvatureThresholdActivity(long iPos,
                 | boolean iCrvtreThsldActivity)
@@ -793,12 +839,14 @@ class HybridShapeExtractMulti(HybridShape):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_distance_threshold(self, i_pos: int, i_distre_thsld: float) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetDistanceThreshold(long iPos,
                 | double iDistreThsld)
@@ -824,6 +872,8 @@ class HybridShapeExtractMulti(HybridShape):
     def set_distance_threshold_activity(self, i_pos: int, i_distre_thsld_activity: bool) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetDistanceThresholdActivity(long iPos,
                 | boolean iDistreThsldActivity)
@@ -860,12 +910,14 @@ class HybridShapeExtractMulti(HybridShape):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_element(self, i_pos: int, i_elem: Reference) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetElement(long iPos,
                 | Reference iElem)
@@ -903,12 +955,14 @@ class HybridShapeExtractMulti(HybridShape):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_is_federated(self, i_pos: int, i_is_federated: bool) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetIsFederated(long iPos,
                 | boolean iIsFederated)
@@ -944,12 +998,14 @@ class HybridShapeExtractMulti(HybridShape):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_propagation_type(self, i_pos: int, i_type_propag: int) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetPropagationType(long iPos,
                 | long iTypePropag)
@@ -983,6 +1039,8 @@ class HybridShapeExtractMulti(HybridShape):
     def set_support(self, i_pos: int, i_support: Reference) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetSupport(long iPos,
                 | Reference iSupport)
@@ -1014,7 +1072,7 @@ class HybridShapeExtractMulti(HybridShape):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
