@@ -17,6 +17,8 @@ from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape
 class HybridShapeExtrapol(HybridShape):
     """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
 
                 | System.IUnknown
@@ -59,6 +61,8 @@ class HybridShapeExtrapol(HybridShape):
     def border_type(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property BorderType() As long
                 | 
@@ -87,6 +91,8 @@ class HybridShapeExtrapol(HybridShape):
     def boundary(self) -> Reference:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Boundary() As Reference
                 | 
@@ -114,6 +120,8 @@ class HybridShapeExtrapol(HybridShape):
     def constant_length_mode(self) -> bool:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property ConstantLengthMode() As boolean
                 | 
@@ -139,6 +147,8 @@ class HybridShapeExtrapol(HybridShape):
     def continuity_type(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property ContinuityType() As long
                 | 
@@ -166,6 +176,8 @@ class HybridShapeExtrapol(HybridShape):
     def elem_to_extrapol(self) -> Reference:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property ElemToExtrapol() As Reference
                 | 
@@ -191,6 +203,8 @@ class HybridShapeExtrapol(HybridShape):
     def elem_until(self) -> Reference:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property ElemUntil() As Reference
                 | 
@@ -218,6 +232,8 @@ class HybridShapeExtrapol(HybridShape):
     def extend_edges_mode(self) -> bool:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property ExtendEdgesMode() As boolean
                 | 
@@ -243,6 +259,8 @@ class HybridShapeExtrapol(HybridShape):
     def extrapol_both_sides_identically(self) -> bool:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property ExtrapolBothSidesIdentically() As boolean
                 | 
@@ -268,6 +286,8 @@ class HybridShapeExtrapol(HybridShape):
     def length(self) -> Length:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Length() As Length (Read Only)
                 | 
@@ -287,6 +307,8 @@ class HybridShapeExtrapol(HybridShape):
     def limit_type(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property LimitType() As long
                 | 
@@ -314,6 +336,8 @@ class HybridShapeExtrapol(HybridShape):
     def propagation_mode(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property PropagationMode() As long
                 | 
@@ -338,6 +362,8 @@ class HybridShapeExtrapol(HybridShape):
     def support(self) -> Reference:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Support() As Reference
                 | 
@@ -363,6 +389,8 @@ class HybridShapeExtrapol(HybridShape):
     def get_boundary(self, i_pos: int) -> Reference:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetBoundary(long iPos) As Reference
                 | 
@@ -384,6 +412,8 @@ class HybridShapeExtrapol(HybridShape):
     def get_continuity_type(self, i_pos: int) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetContinuityType(long iPos) As long
                 | 
@@ -403,6 +433,8 @@ class HybridShapeExtrapol(HybridShape):
     def get_elem_until(self, i_pos: int) -> Reference:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetElemUntil(long iPos) As Reference
                 | 
@@ -421,6 +453,8 @@ class HybridShapeExtrapol(HybridShape):
     def get_internal_edges_element(self, i_pos: int) -> Reference:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetInternalEdgesElement(long iPos) As Reference
                 | 
@@ -443,6 +477,8 @@ class HybridShapeExtrapol(HybridShape):
     def get_length(self, i_pos: int) -> Length:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetLength(long iPos) As Length
                 | 
@@ -461,6 +497,8 @@ class HybridShapeExtrapol(HybridShape):
     def get_limit_type(self, i_pos: int) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetLimitType(long iPos) As long
                 | 
@@ -480,6 +518,8 @@ class HybridShapeExtrapol(HybridShape):
     def get_number_of_extrapolations(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetNumberOfExtrapolations(long
                 | oNumberOfExtrapolations)
@@ -496,6 +536,8 @@ class HybridShapeExtrapol(HybridShape):
     def is_assemble(self) -> bool:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func IsAssemble() As boolean
                 | 
@@ -517,6 +559,8 @@ class HybridShapeExtrapol(HybridShape):
     def remove_all_extrapolations_except_the_first_one(self) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveAllExtrapolationsExceptTheFirstOne()
                 | 
@@ -530,6 +574,8 @@ class HybridShapeExtrapol(HybridShape):
     def remove_all_internal_edges_element(self) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveAllInternalEdgesElement()
                 | 
@@ -543,6 +589,8 @@ class HybridShapeExtrapol(HybridShape):
     def remove_extrapolation(self, i_pos: int) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveExtrapolation(long iPos)
                 | 
@@ -557,6 +605,8 @@ class HybridShapeExtrapol(HybridShape):
     def set_assemble(self, i_assemble: bool) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetAssemble(boolean iAssemble)
                 | 
@@ -588,12 +638,14 @@ class HybridShapeExtrapol(HybridShape):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_boundary(self, i_pos: int, i_boundary: Reference) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetBoundary(long iPos,
                 | Reference iBoundary)
@@ -617,12 +669,14 @@ class HybridShapeExtrapol(HybridShape):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_continuity_type(self, i_pos: int, i_lim: int) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetContinuityType(long iPos,
                 | long iLim)
@@ -637,6 +691,8 @@ class HybridShapeExtrapol(HybridShape):
     def set_elem_until(self, i_pos: int, i_elem_until: Reference) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetElemUntil(long iPos,
                 | Reference iElemUntil)
@@ -660,12 +716,14 @@ class HybridShapeExtrapol(HybridShape):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_length(self, i_pos: int, i_length: Length) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetLength(long iPos,
                 | Length iLength)
@@ -691,12 +749,14 @@ class HybridShapeExtrapol(HybridShape):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_length_d(self, i_pos: int, i_length: float) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetLengthD(long iPos,
                 | double iLength)
@@ -711,6 +771,8 @@ class HybridShapeExtrapol(HybridShape):
     def set_limit_type(self, i_pos: int, i_lim: int) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetLimitType(long iPos,
                 | long iLim)
