@@ -18,6 +18,8 @@ from pycatia.in_interfaces.window import Window
 from pycatia.in_interfaces.windows import Windows
 from pycatia.system_interfaces.any_object import AnyObject
 from pycatia.system_interfaces.system_service import SystemService
+from pycatia.in_interfaces.setting_controllers import SettingControllers
+from pycatia.types.document_types import document_type
 
 
 class Application(AnyObject):
@@ -90,7 +92,9 @@ class Application(AnyObject):
         :rtype: Document
         """
         try:
-            return Document(self.com_object.ActiveDocument)
+            active_doc_com = self.com_object.ActiveDocument
+            doc_suffix = active_doc_com.Name.split('.')[-1]
+            return document_type[doc_suffix](active_doc_com)
         except com_error:
             raise CATIAApplicationException('Is there an active document?')
 
@@ -1206,6 +1210,12 @@ class Application(AnyObject):
         """
         return self.com_object.Quit()
 
+    def setting_controllers(self):
+        """
+        Application.SettingControllers
+        """
+        return SettingControllers(self.com_object.SettingControllers)
+
     def start_command(self, i_command_id: str) -> None:
         """
         .. note::
