@@ -8,6 +8,7 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
 
 from pycatia.in_interfaces.light_source import LightSource
 from pycatia.system_interfaces.collection import Collection
@@ -133,5 +134,9 @@ class LightSources(Collection):
 
         return LightSource(self.light_sources.item(n + 1))
 
+    def __iter__(self) -> Iterator[LightSource]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'LightSources(name="{self.name}")'
