@@ -8,6 +8,7 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
 
 from pycatia.system_interfaces.collection import Collection
 from pycatia.system_interfaces.setting_controller import SettingController
@@ -32,9 +33,10 @@ class SettingControllers(Collection):
     
     """
 
-    def __init__(self, caa):
-        super().__init__(caa.com_object, child_object=SettingController)
-        self.setting_controllers = caa.com_object.SettingControllers
+    def __init__(self, com_object):
+        super().__init__(com_object, child_object=SettingController)
+        self.setting_controllers = com_object
+        self.child_object = SettingController
 
     def item(self, i_index: str) -> SettingController:
         """
@@ -70,5 +72,9 @@ class SettingControllers(Collection):
 
         return SettingController(self.setting_controllers.item(n + 1))
 
+    def __iter__(self) -> Iterator[SettingController]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'SettingControllers(name="{self.name}")'
