@@ -8,7 +8,7 @@
         and thus help debugging in pycatia.
         
 """
-
+from typing import Iterator
 from pathlib import Path
 
 from pycatia.exception_handling.exceptions import CATIAApplicationException
@@ -22,7 +22,7 @@ from pycatia.knowledge_interfaces.rule import Rule
 from pycatia.knowledge_interfaces.set_of_equation import SetOfEquation
 from pycatia.system_interfaces.any_object import AnyObject
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class Relations(Collection):
@@ -634,5 +634,9 @@ class Relations(Collection):
 
         return Relation(self.relations.item(n + 1))
 
+    def __iter__(self) -> Iterator[Relation]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Relations(name="{self.name}")'
