@@ -17,6 +17,8 @@ from pycatia.system_interfaces.any_object import AnyObject
 class Constraint(AnyObject):
     """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
 
                 | System.IUnknown
@@ -39,6 +41,8 @@ class Constraint(AnyObject):
     def angle_sector(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                 | o Property AngleSector() As CatConstraintAngleSector
                 |
@@ -99,6 +103,8 @@ class Constraint(AnyObject):
     def dimension(self) -> Dimension:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                 | o Property Dimension() As Dimension (Read Only)
                 |
@@ -123,6 +129,8 @@ class Constraint(AnyObject):
     def distance_config(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                 | o Property DistanceConfig() As CatConstraintDistConfig
                 |
@@ -156,6 +164,8 @@ class Constraint(AnyObject):
     def distance_direction(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                 | o Property DistanceDirection() As CatConstraintDistDirection
                 |
@@ -185,6 +195,8 @@ class Constraint(AnyObject):
     def mode(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                 | o Property Mode() As CatConstraintMode
                 |
@@ -217,6 +229,8 @@ class Constraint(AnyObject):
     def orientation(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                 | o Property Orientation() As CatConstraintOrientation
                 |
@@ -249,6 +263,8 @@ class Constraint(AnyObject):
     def reference_axis(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                 | o Property ReferenceAxis() As CatConstraintRefAxis
                 |
@@ -281,6 +297,8 @@ class Constraint(AnyObject):
     def reference_type(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                 | o Property ReferenceType() As CatConstraintRefType
                 |
@@ -311,6 +329,8 @@ class Constraint(AnyObject):
     def side(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                 | o Property Side() As CatConstraintSide
                 |
@@ -342,6 +362,8 @@ class Constraint(AnyObject):
     def status(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                 | o Property Status() As CatConstraintStatus (Read Only)
                 |
@@ -364,6 +386,8 @@ class Constraint(AnyObject):
     def type(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                 | o Property Type() As CatConstraintType (Read Only)
                 |
@@ -384,6 +408,8 @@ class Constraint(AnyObject):
     def activate(self) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Sub Activate()
                 |
@@ -406,6 +432,8 @@ class Constraint(AnyObject):
     def deactivate(self) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Sub Deactivate()
                 |
@@ -427,6 +455,8 @@ class Constraint(AnyObject):
     def get_constraint_element(self, i_element_number: int) -> Reference:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Func GetConstraintElement(long iElementNumber) As
                 | Reference
@@ -458,6 +488,8 @@ class Constraint(AnyObject):
     def get_constraint_visu_location(self, o_anchor_point: tuple, o_anchor_vector: tuple) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Sub GetConstraintVisuLocation(CATSafeArrayVariant
                 | oAnchorPoint,
@@ -506,12 +538,14 @@ class Constraint(AnyObject):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def is_inactive(self) -> bool:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Func IsInactive() As boolean
                 |
@@ -533,6 +567,8 @@ class Constraint(AnyObject):
     def set_constraint_element(self, i_element_number: int, i_new_element: Reference) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Sub SetConstraintElement(long iElementNumber,
                 | Reference iNewElement)
@@ -573,12 +609,14 @@ class Constraint(AnyObject):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_constraint_visu_location(self, i_new_x: float, i_new_y: float, i_new_z: float) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Sub SetConstraintVisuLocation(double iNewX,
                 | double iNewY,
