@@ -73,7 +73,7 @@ class CylindricalFace(Face):
         super().__init__(com_object)
         self.cylindrical_face = com_object
 
-    def get_direction(self, o_direction=None):
+    def get_direction(self) -> tuple:
         """
         .. note::
             :class: toggle
@@ -95,24 +95,20 @@ class CylindricalFace(Face):
         :param tuple o_direction:
         :return: None
         """
-        return self.cylindrical_face.GetDirection(o_direction)
-        # # # # Autogenerated comment:
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_direction'
-        # # vba_code = """
-        # # Public Function get_direction(cylindrical_face)
-        # #     Dim oDirection (2)
-        # #     cylindrical_face.GetDirection oDirection
-        # #     get_direction = oDirection
-        # # End Function
-        # # """
 
-        # # system_service = self.application.system_service
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_direction'
+        vba_code = """
+        Public Function get_direction(cylindrical_face)
+            Dim oDirection (2)
+            cylindrical_face.GetDirection oDirection
+            get_direction = oDirection
+        End Function
+        """
 
-    def get_origin(self, o_origin: tuple) -> None:
+        system_service = self.application.system_service
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+
+    def get_origin(self) -> tuple:
         """
         .. note::
             :class: toggle
@@ -135,22 +131,18 @@ class CylindricalFace(Face):
         :return: None
         :rtype: None
         """
-        return self.cylindrical_face.GetOrigin(o_origin)
-        # # # # Autogenerated comment:
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_origin'
-        # # vba_code = """
-        # # Public Function get_origin(cylindrical_face)
-        # #     Dim oOrigin (2)
-        # #     cylindrical_face.GetOrigin oOrigin
-        # #     get_origin = oOrigin
-        # # End Function
-        # # """
 
-        # # system_service = self.application.system_service
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_origin'
+        vba_code = """
+        Public Function get_origin(cylindrical_face)
+            Dim oOrigin (2)
+            cylindrical_face.GetOrigin oOrigin
+            get_origin = oOrigin
+        End Function
+        """
+
+        system_service = self.application.system_service
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
         return f'CylindricalFace(name="{self.name}")'
