@@ -8,10 +8,11 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
 
 from pycatia.part_interfaces.defeaturing_filter import DefeaturingFilter
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class DefeaturingFilters(Collection):
@@ -141,5 +142,9 @@ class DefeaturingFilters(Collection):
 
         return DefeaturingFilter(self.defeaturing_filters.item(n + 1))
 
+    def __iter__(self) -> Iterator[DefeaturingFilter]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'DefeaturingFilters(name="{self.name}")'
