@@ -8,12 +8,12 @@
         and thus help debugging in pycatia.
         
 """
-
+from typing import Iterator
 from typing import TYPE_CHECKING
 
 from pycatia.product_structure_interfaces.publication import Publication
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 if TYPE_CHECKING:
     from pycatia.in_interfaces.reference import Reference
@@ -241,5 +241,9 @@ class Publications(Collection):
 
         return Publication(self.publications.item(n + 1))
 
+    def __iter__(self) -> Iterator[Publication]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Publications(name="{self.name}")'
