@@ -8,9 +8,11 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
+
 from pycatia.space_analyses_interfaces.conflict import Conflict
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class Conflicts(Collection):
@@ -77,5 +79,9 @@ class Conflicts(Collection):
 
         return Conflict(self.conflicts.item(n + 1))
 
+    def __iter__(self) -> Iterator[Conflict]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Conflicts(name="{self.name}")'
