@@ -8,10 +8,12 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
+
 from pycatia.space_analyses_interfaces.inertia import Inertia
 from pycatia.system_interfaces.any_object import AnyObject
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class Inertias(Collection):
@@ -157,5 +159,9 @@ class Inertias(Collection):
 
         return Inertia(self.inertias.item(n + 1))
 
+    def __iter__(self) -> Iterator[Inertia]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Inertias(name="{self.name}")'
